Module types

Module types 

Structs

FixedParameters
Fixed parameters that are not calibrated by the optimizer
MarketDataRow
Minimal market data structure with only essential fields for surface calibration
PricingResult
Lightweight struct to hold the essential pricing results for each option

Traits

ModelCalibrator
Model calibrator trait for parameter optimization