pub fn linear_interp(sorted_points: &[(f64, f64)], query_x: f64) -> Option<f64>
Linear interpolation in variance space Returns None if query_x is outside the range and extrapolation is disabled or fails